@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 # synadm
-# Copyright (C) 2020-2021 Johannes Tiefenbacher
+# Copyright (C) 2020-2022 Johannes Tiefenbacher
 #
 # synadm is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -33,7 +33,7 @@ def group():
 @click.argument("group_id", type=str)
 @click.pass_obj
 def delete(helper, group_id):
-    """ delete a local group (community)
+    """ Delete a local group (community)
     """
     sure = (
         helper.batch or
@@ -48,4 +48,3 @@ def delete(helper, group_id):
         helper.output(group_del)
     else:
         click.echo("Abort.")
-
